
{% if migration.labels_processed %}
    <div class="msg msg-info"><p>Processing messages...</p></div>
    <div class="msg msg-ok"><p>Imported messages: {{ migration.messages_cnt }}.</p></div>
    <div class="msg msg-ok"><p>Current date: {{ migration.current_since }}.</p></div>
{% else %}
    <div class="msg msg-info"><p>Processing labels...</p></div>
    <div class="msg msg-ok"><p>Finished label: {{ sane_label|default:"[just started]" }}</p></div>
{% endif %}
<span class="loading" style="display: none"></span>
