
{% extends "migration.html" %}

{% block title %}Migration finished{% endblock %}
{% block h1 %}Migration finished!{% endblock %}

{% block right_content %}
<div class="box box-50">
    <div class="boxin">
        <div class="header">
            <h3>Migration finished</h3>
        </div>
        <div class="boxcontent">
            <div class="msg msg-ok"><p>Migration finished, thank you.</p></div>
            <div class="msg msg-ok"><p>Imported messages: {{ migration.messages_cnt }}.</p></div>
            <div class="msg msg-info"><p>Password data cleaned from database.</p></div>
            <a class="button" href="{% url migrate_mail.index %}">Create new migration</a>
        </div>
    </div>
</div>
{% endblock %}