<!DOCTYPE html>
<html>

<head>

    <title>{% block title %}Dashboard{% endblock %} · Gmail Migration Tool</title>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <link rel="stylesheet" type="text/css" href="{% url migrate_mail.index %}static/black.css" media="screen, projection, tv">
    <script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.js"></script>
    <script type="text/javascript">
        $(document).ready(function() {
            // Search input text handling on focus
                var $searchq = $("#search-q").attr("value");
                $('#search-q.text').css('color', '#999');
                $('#search-q').focus(function(){
                    if ( $(this).attr('value') == $searchq) {
                        $(this).css('color', '#555');
                        $(this).attr('value', '');
                    }
                });
                $('#search-q').blur(function(){
                    if ( $(this).attr('value') == '' ) {
                        $(this).attr('value', $searchq);
                        $(this).css('color', '#999');
                    }
                });
            // Handling with tables (adding first and last classes for borders and adding alternate bgs)
                $('tbody tr:even').addClass('even');
                $('table.grid tbody tr:last-child').addClass('last');
                $('tr th:first-child, tr td:first-child').addClass('first');
                $('tr th:last-child, tr td:last-child').addClass('last');
                $('form.fields fieldset:last-child').addClass('last');
            // Handling with lists (alternate bgs)
                $('ul.simple li:even').addClass('even');
            // Handling with grid views (adding first and last classes for borders and adding alternate bgs)
                $('.grid .line:even').addClass('even');
                $('.grid .line:first-child').addClass('firstline');
                $('.grid .line:last-child').addClass('lastline');
            // box heigth
                $('.box, .boxin').css('height', $('#container').innerHeight() - $('#footer').innerHeight() - 60);
        });
    </script>

</head>
<body>

<div id="nav">
    <div class="inner-container clearfix">
        <div id="h-wrap">
            <div class="inner">
                <h2>
                    {% block h1 %}Gmail Migration Tool{% endblock %}
                </h2>
            </div>
        </div><!-- #h-wrap -->
        <div id="fix"></div>
    </div><!-- .inner-container -->
</div><!-- #nav -->

<div id="container">
    <div class="inner-container">
        
        {% block left_content %}{% endblock %}
        {% block right_content %}{% endblock %}
    
        <div id="footer">
            <p>&copy; Boutique.ru, 2011</p>
        </div>
    
    </div><!-- .inner-container -->
</div><!-- #container -->
        
    
</body>
